@@ -3,8 +3,8 @@ import logging
 import os
 import sys
 import textwrap
+from unittest import mock
 
-import mock
 import pytest
 import sh
 
@@ -259,8 +259,9 @@ def test_load_dotenv_no_file_verbose():
     logger = logging.getLogger("dotenv.main")
 
     with mock.patch.object(logger, "info") as mock_info:
-        dotenv.load_dotenv('.does_not_exist', verbose=True)
+        result = dotenv.load_dotenv('.does_not_exist', verbose=True)
 
+    assert result is False
     mock_info.assert_called_once_with("Python-dotenv could not find configuration file %s.", ".does_not_exist")
 
 
